;;these are global level variables that can be accessed by individuals, groups, and the observer
globals [
emptyCell
totalCultTransEvents
totalGroupExtinctions
totalGroupFissions
timeToCollect
totalDiversity
totalDiversityList
totalFrequencyList
H_global
H_t
H_s
t_f
ShannonsIndex
meanDiffFromAncestral
CVDiffFromAncestral
maxDiffFromAncestral
meanHofGroups
varHofGroups
meanSIofGroups
varSIofGroups
meanDiffOtherGroups
CVDiffOtherGroups
totalNumberFissions  
meanNumberGroupFissions 
varNumberGroupFissions  
]

;;these are the state variables of individuals
turtles-own [
culturalVariant
errorProb
age
]

;;these are the state variables of groups
patches-own [
modeCulturalVariant
H
ShannonsIndexGroup
groupExtinctionProb
differenceFromAncestral
differenceToAllOtherGroups
withinGroupDiversity
withinGroupDiversityList
withinGroupFrequencyList
withinGroupHtList
fissions
extinctions
]




to setup  ;;this is the first method run when starting a simulation run
ca  ;;short for "clear all", this gets rid of anything that may have been left over from a previous run

;;if file-exists? "diversityData.txt"   ;;when doing parameter sweep, comment these 2 lines out so as to collect all experiment data on one file
;; [file-delete "diversityData.txt"]    ;;leaving these 2 lines uncommented means that each subsequent run will overwrite the previous run's data file


if collectData = true
[
 file-open "diversityData.txt"   ;;open file and write new header info to it
 file-print " "
 file-write "seed worldSizeX worldSizeY conformistLearning maxGroupSize groupExtinctionProbMean groupExtinctionProbStandDev localReplacement replaceBasedOnSize innovationType errorRateMean errorRateStandDev dataCollectionInterval intialPopulation experimentDuration" file-print " "
 file-write seed file-write (max-pxcor + 1) file-write (max-pycor + 1) file-write conformistLearning file-write maxGroupSize file-write groupExtinctionProbMean file-write groupExtinctionProbStandDev file-write localReplacement file-write replaceBasedOnSize file-write innovationType file-write errorRateMean file-write errorRateStandDev file-write dataCollectionInterval file-write initialPopulation file-write experimentDuration
 file-print " "
 file-write "Time PopSize Variants SI H_global Ht Hs tF meanDA CVDA maxDA CTE Extinctions Fissions meanFissions varFissions meanH varH meanDO CVDO meanSIGroup varSIGroup" file-print " "
 file-close
]

;;set time to zero
reset-ticks

;;use the "seed" provided to seed the random number generator
random-seed seed

set timeToCollect 0

;;create the starting population of agents
ask patches 
  [
  sprout maxGroupSize [initIndividual]  ;;this tells each patch to create individuals, the number of which is defined by maxGroupSize

  ;;each group's local extinction probability (e) is drawn from a normal distribution with a user-defined mean and standard deviation
  set groupExtinctionProb random-normal groupExtinctionProbMean groupExtinctionProbStandDev  
  if groupExtinctionProb < 0  ;;we cannot have a groupExtinctionProb less than zero
   [
   set groupExtinctionProb 0
   ]
  if groupExtinctionProb > 1  ;;we cannot have a groupExtinctionProb greater than 1
   [
   set groupExtinctionProb 1
   ]
  
  set fissions 0
  set extinctions 0
  ]

end




to initIndividual  ;;called by the "setup" method, this sets the variable values in each starting individual

ifelse initialPopulation = "heterogeneous"
[
set culturalVariant random 100000000  ;;the initial population starts with individuals who have very different variants, this is the option used to collect the equilibrium condition results
]
[
set culturalVariant 0  ;;the initial population starts with the ancestral state (all zeros), this is the option used to collect the non-equilibrium condition results
]


set age 0

;;each individual's probability of making a copying error (mu) is drawn from a normal distribution with a user-defined mean and standard deviation
set errorProb random-normal errorRateMean errorRateStandDev
if errorProb < 0  ;;we cannot have an errorProb less than zero
 [
 set errorProb 0
 ]
if errorProb > 1  ;;we cannot have an errorProb greater than one
 [
 set errorProb 1
 ]
 
;;all individuals will be colored blue to start, but their color will change with culturalVariant henceforth
set color blue
end




to go  ;;This is the model's "step" function, which is executed during each and every time step.  The order in which other methods are invoked within this method is important.

;;Stage 1: turtles "age" to become the parental generation
ask turtles [set age 1]


;;Stage 2a: each group is exposed to local extinction...
ask patches [localExtinction]


;;Stage 2b: ...and empty cells are recolonized locally
ask patches with [count turtles-here = 0] [recolonization]


;;Stage 3: produce new generation of turtles in each patch
ask patches [createNaiveGeneration]


;;Stage 4:the new generation of indiviuduals learns from the members of the parental generation in their group
ask turtles with [age = 0] [cultTransmission]


;;Stage 5: after cultural transmission, kill off all turtles with age = 1 (members of the parental generation)
ask turtles with [age = 1] [die]


;;time passes, this increments "ticks" by one
tick


;;;;collect data when necessary
if ticks = timeToCollect or ticks = 1 or ticks = experimentDuration   ;; if it is time to calculate diversity measures
 [
 calculateTotalDiversity  ;;calculate lists of unique strings and their relative frequencies, THIS MUST BE DONE BEFORE THE DIVERSITY MEASURES ARE CALCULATED BELOW, THEY RELY UPON IT
 
 ;;calculate global measure of average cultural diversity, H (Nei and Kumar 2000: equ. 12.41)
 calculateH_global   ;;NOTE: Do *not* use this measure in the analysis!!  Use H_t instead, it is better!!

 ;;calculate global measure of average cultural diversity (multiple variants at a single locus), Ht (Nei and Kumar 2000: equ. 12.43)
 ask patches
  [
  calculateWithinGroupPortionOfHt  ;;see method below
  ]
 calculateHt   ;;see method below, NOTE: this method *must* be called after (not before) calculateWithinGroupPortionOfHt
 calculateShannonIndex  ;;calculate another global measure of average cultural diversity  (see method below)
 calculateNumberUniqueVariantsWithinGroups
 calculateShannonIndexGroups
 calculateHs    ;;within-groups component of total diversity, Hs (see Nei and Kumar 2000: equ 12.42)
 calculateH
 
 
;;update the modal lists of the patches after individuals have gone through cultural transmission
ask patches  ;;ask all patches to reset their modal variant to the mode of the variants their members display (ties for modes broken randomly)
[
set modeCulturalVariant one-of modes [culturalVariant] of turtles-here
]


ask patches
[
if any? turtles-here
 [
 calculateDifferenceFromAncestral   ;;for all patches that contain individuals, calculate their cultural difference from the ancestral state
 ]
]

ask patches
[
if any? turtles-here
 [
 calculateDifferenceToAllOtherGroups  ;;for all patches that contain individuals, calculate their cultural difference from all other groups
 ]
]


;;recolor patches, such that the group that is most different from ancestral is white and all others a darker shade of red
let maximumDifference max [differenceFromAncestral] of patches
ask patches
[
set pcolor scale-color red differenceFromAncestral 0 (maximumDifference + 0.000001)  ;;"red" can be changed to any color you prefer
]
 
 
 
 if collectData = true  ;;if true, we would like to collect data on the measures we have just calculated
 [
 ;;set remaining variables here
 set meanDiffFromAncestral mean([differenceFromAncestral] of patches) 
 set maxDiffFromAncestral max([differenceFromAncestral] of patches) 
 ifelse meanDiffFromAncestral > 0
 [
 set CVDiffFromAncestral (standard-deviation([differenceFromAncestral] of patches) / mean([differenceFromAncestral] of patches)) 
 ]
 [
 set CVDiffFromAncestral 0
 ] 
 set meanNumberGroupFissions mean([fissions] of patches) 
 set varNumberGroupFissions variance([fissions] of patches) 
 set meanHofGroups mean([H] of patches) 
 set meanSIofGroups mean([ShannonsIndexGroup] of patches)
 set varSIofGroups variance([ShannonsIndexGroup] of patches)
 set varHofGroups variance([H] of patches)
 set meanDiffOtherGroups mean([differenceToAllOtherGroups] of patches) 
 ifelse meanDiffOtherGroups > 0
 [
 set CVDiffOtherGroups (standard-deviation([differenceToAllOtherGroups] of patches) / mean([differenceToAllOtherGroups] of patches)) 
 ]
 [
 set CVDiffOtherGroups 0
 ]
 
 printOutput   ;;invoke the printOutput method (see below) so that we can write data to the textfile we created in "setup"
 ]

 set timeToCollect timeToCollect + dataCollectionInterval   ;;reset timeToCollect so that we will collect data again in due time
]

;;Plotting in the interface during a simulation run
;;update plots with fresh data.  Note that these plots will not show up when running in batch mode from the command line.
set-current-plot "Difference from Ancestral State (Histogram)"
clear-plot
auto-plot-on
histogram [differenceFromAncestral] of patches

set-current-plot "Difference from Ancestral State"
auto-plot-on
set-current-plot-pen "mean"
plot mean [differenceFromAncestral] of patches
set-current-plot-pen "sd"
plot standard-deviation [differenceFromAncestral] of patches
set-current-plot-pen "var"
plot variance [differenceFromAncestral] of patches
ifelse mean [differenceFromAncestral] of patches > 0
[
set-current-plot-pen "CV"
plot (standard-deviation [differenceFromAncestral] of patches) / (mean [differenceFromAncestral] of patches)
]
[
set-current-plot-pen "CV"
plot 0
]


set-current-plot "Difference from All Other Groups"
auto-plot-on
set-current-plot-pen "mean"
plot mean [differenceToAllOtherGroups] of patches
set-current-plot-pen "sd"
plot standard-deviation [differenceToAllOtherGroups] of patches
set-current-plot-pen "var"
plot variance [differenceToAllOtherGroups] of patches
ifelse mean [differenceToAllOtherGroups] of patches > 0
[
set-current-plot-pen "CV"
plot (standard-deviation [differenceToAllOtherGroups] of patches) / (mean [differenceToAllOtherGroups] of patches)
]
[
set-current-plot-pen "CV"
plot 0
]


set-current-plot "Group Cultural Diversity"
auto-plot-on
set-current-plot-pen "mean"
plot mean [H] of patches
set-current-plot-pen "sd"
plot standard-deviation [H] of patches
set-current-plot-pen "var"
plot variance [H] of patches
set-current-plot-pen "CV"
ifelse mean [H] of patches > 0
[
plot (standard-deviation [H] of patches) / (mean [H] of patches)
]
[
plot (0)
]

set-current-plot "Difference from All Other Groups (Histogram)"
clear-plot
auto-plot-on
histogram [differenceToAllOtherGroups] of patches


set-current-plot "Population Cultural Diversity"
auto-plot-on
set-current-plot-pen "Total"
plot H_t
set-current-plot-pen "Within"
plot H_s
set-current-plot-pen "Between"
plot (H_t - H_s)


if ticks = experimentDuration
[
stop  ;; this stops the simulation when the number of time steps elapsed matches the user-defined value of experimentDuration
]

end
;;this ends the "go" method





to localExtinction  ;;patches method, called in "go"

if random-float 1 <= groupExtinctionProb  ;;if a random uniform float is less than or equal to group extinction prob
 [
 ask turtles-here [die]   ;;all of the individuals in the group die and are removed from the simulation immediately
 set extinctions extinctions + 1   ;;local variable: increment the number of the group's extinctions by one
 set totalGroupExtinctions totalGroupExtinctions + 1   ;;global variable: increment the total number of group extinctions (i.e., a tally of all extinctions in the metapopulation)
 ]
end





to recolonization  ;; patches method, called in "go"
;;empty patches initiate the colonization processes by telling a neighboring patch to colonize it   
 set emptyCell self
 ifelse localReplacement = true   ;;if true, this means that the colonizing group can only come from emptyCell's local Moore neighborhood
    [
    ifelse replaceBasedOnSize = true  ;;if true, this means that the colonizing group will be the largest in emptyCell's local Moore neighborhood
      [
      ask max-one-of neighbors [count turtles-here]   ;;ask the group with the most members (ties broken randomly) ...
        [
        colonize   ;;...to colonize emptyCell (see "colonize" method below) ...
        set fissions fissions + 1  ;;...and to increment the number of times it has fissioned
        set totalGroupFissions totalGroupFissions + 1   ;;...and to increment the total number of fission events. 
        ]
      ]
      [;else, the colonizing group does not need to be the most populated
      ask one-of neighbors with [count turtles-here > 1] ;;just randomly choose one of the local neighbors with at least 2 individuals and ask it...
        [
        colonize   ;;...to colonize emptyCell (see "colonize" method below) ...
        set fissions fissions + 1 ;;local variable, increment the number of times this group has fissoned
        set totalGroupFissions totalGroupFissions + 1    ;;global variable, increment the total number of fission events.
        ]
      ]
    ]  
    [;;else, the colonizing group can come from anywhere in the world...this is no longer a spatially explicit rule
    ifelse replaceBasedOnSize = true  ;;if true, this means that the colonizing group will be the largest in the entire world
      [
      ask max-one-of patches [count turtles-here]
        [
        colonize   ;;...to colonize emptyCell (see "colonize" method below) ...
        set fissions fissions + 1  ;;...and to increment the number of times it has fissioned
        set totalGroupFissions totalGroupFissions + 1    ;;...and increment the number of fissioning events.
        ]
      ]
      [;;else, the colonizing group does not need to be the most populated
      ask one-of patches with [count turtles-here > 1]   ;;just randomly choose one of the groups that have at least 2 individuals from the whole world and ask it...
        [
        colonize  ;;...to colonize emptyCell (see "colonize" method below) ...
        set fissions fissions + 1 ;;...and to increment the number of times it has fissioned.
        set totalGroupFissions totalGroupFissions + 1  ;;...and increment the number of fissioning events.
        ]
      ]
    ]
end



to createNaiveGeneration  ;;patches method, called in "go"

sprout maxGroupSize ;;create a new generation of (naive) individuals in the patch
 [
 set age 0  ;;this identifies them as naive
 set culturalVariant 0  ;;naive individuals start with culturalVariant=0


;;each individual's probability of making a copying error (mu) is drawn from a normal distribution with a user-defined mean and standard deviation
set errorProb random-normal errorRateMean errorRateStandDev
if errorProb < 0  ;;we cannot have an errorProb less than zero
 [
 set errorProb 0
 ]
if errorProb > 1  ;;we cannot have an errorProb greater than one
 [
 set errorProb 1
 ]
 set color blue
 ]
end





to calculateTotalDiversity   ;;observer method
set totalDiversityList (list)
;;show totalDiversityList  ;;LSP for testing only
set totalFrequencyList (list)

ask turtles
 [
 let myVariant culturalVariant
 ifelse member? myVariant totalDiversityList = false
  [
  set totalDiversityList lput myVariant totalDiversityList
  ;;show totalDiversityList  ;;LSP for testing only
  set totalFrequencyList lput 1 totalFrequencyList
  ]
  [
  let oldFrequency item (position myVariant totalDiversityList) totalFrequencyList
  ;;show oldFrequency  ;;for testing only
  ;;show totalFrequencyList  ;;for testing only
  set totalFrequencyList replace-item (position myVariant totalDiversityList) totalFrequencyList (oldFrequency + 1)
  ;;show totalFrequencyList  ;;for testing only
  ]
 ]

set totalDiversity length totalDiversityList
;;show length totalDiversityList  ;;LSP for testing only
end





to calculateNumberUniqueVariantsWithinGroups 
 ;;calculate Number Of Unique variants Within Groups
 ask patches
 [
  let withinGroupDiversityListTemp (list)
  ;;show withinGroupDiversityListTemp  ;;LSP for testing only
  let withinGroupFrequencyListTemp (list)
 
  ask turtles-here
  [
  let myVariant culturalVariant
  ifelse member? myVariant withinGroupDiversityListTemp = false
   [
   set withinGroupDiversityListTemp lput myVariant withinGroupDiversityListTemp
   ;;show withinGroupDiversityListTemp  ;;LSP for testing only
   set withinGroupFrequencyListTemp lput 1 withinGroupFrequencyListTemp
   ;;show withinGroupFrequencyListTemp  ;;for testing only
   ]
   [
   let oldFrequency item (position myVariant withinGroupDiversityListTemp) withinGroupFrequencyListTemp
   ;;show oldFrequency  ;;for testing
   ;;show withinGroupFrequencyListTemp  ;;for testing only
   set withinGroupFrequencyListTemp replace-item (position myVariant withinGroupDiversityListTemp) withinGroupFrequencyListTemp (oldFrequency + 1)
   ;;show withinGroupFrequencyListTemp  ;;for testing only
   ] 
  ]
 set withinGroupDiversityList withinGroupDiversityListTemp
 ;;show length withinGroupDiversityList  ;;LSP for testing only
 set withinGroupDiversity length withinGroupDiversityList 
 set withinGroupFrequencyList withinGroupFrequencyListTemp
 ]
end




to calculateH_global    ;;NOTE: this is not a correct use of H for cases where group sizes can vary
let sumOfSquares 0

foreach totalFrequencyList
 [
 set sumOfSquares sumOfSquares + ((? / count turtles) ^ 2)
 ]

set H_global (1 - sumOfSquares)
;;write "H_global:"  ;;for testing
;;print H_global  ;;for testing
end





to calculateHs 
 ;;calculate Hs (Nei and Kumar 2000: equ. 12.42)
 let weightedSumOfSquares 0
 ask patches
  [
  let sumOfSquares 0
  foreach withinGroupFrequencyList
   [
   set sumOfSquares sumOfSquares + ((? / count turtles-here) ^ 2)
   ]
  set weightedSumOfSquares weightedSumOfSquares + ((count turtles-here / count turtles)  * sumOfSquares)
  ]

 set H_s (1 - weightedSumOfSquares)
 ;;write "Hs:"  ;;for testing and printing out to the GUI
 ;;print H_s  ;;for testing and printing out to the GUI
end ;;end calculateHs





to calculateH 
 ;;calculate H for each subgroup.  NOTE: this is a better use of H (Nei and Kumar 2000, Eq. 12.41)
 ask patches
 [
 let sumOfSquares 0

 foreach withinGroupFrequencyList
  [
  set sumOfSquares sumOfSquares + ((? / count turtles-here) ^ 2)
  ]
 set H (1 - sumOfSquares)
 ]
end 




to calculateShannonIndex
let summation 0

foreach totalFrequencyList
 [
 set summation summation + ((? / count turtles) * (ln (? / count turtles)))
 ]

set ShannonsIndex (-1 * summation)
;;write "Shannon Index:" 
;;print ShannonsIndex  ;;for testing
end




to calculateShannonIndexGroups   ;;patches method
ask patches
[
let summation 0

foreach withinGroupFrequencyList
 [
 set summation summation + ((? / count turtles-here) * (ln (? / count turtles-here)))
 ]

set ShannonsIndexGroup (-1 * summation)
;;write "Shannons Index Group:" 
;;print ShannonsIndexGroup  ;;for testing
]
end




to calculateWithinGroupPortionOfHt  ;;this is a patches method
set withinGroupHtList n-values (length totalDiversityList) [0]
;;show withinGroupHtList  ;;LSP for testing only

let numberOfTurtlesInTheGroup count turtles-here

ask turtles-here
 [
 let myVariant culturalVariant

 let oldFrequency item (position myVariant totalDiversityList) [withinGroupHtList] of myself
 ;;show oldFrequency  ;;for testing only

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;; PLEASE NOTE: these changes were made to make the original code compatible with NetLogo version 4.1.1
;; The next 7 lines of code were added to replace the commented line below (which is marked with ;;***;;) so that the model is compatible with the most recent version of NetLogo (version 4.1.1) [also note that it is still compatible with version 4.0]
 let newFrequency (oldFrequency + (1 / numberOfTurtlesInTheGroup))
 ;;show newFrequency  ;;for testing only
 
 ask patch-here
 [
 set withinGroupHtList replace-item (position myVariant totalDiversityList) withinGroupHtList newFrequency
 ]
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

 ;;;;;;;;;The line below (marked ;;***;;) worked in NetLogo 4.0, but it does NOT work in NetLogo 4.1.  For that reason, it has been replaced by the 7 lines above. 
 ;;;;;;;;;I have left the line in (but commented out) for completeness; we collected our data in Netlogo 4.0.4 with this line uncommented and without the new code above.  
 ;;;;;;;;;There is no qualitative difference in the results due to this change in syntax.

 ;;***;; set [withinGroupHtList] of myself replace-item (position myVariant totalDiversityList) [withinGroupHtList] of myself (oldFrequency + (1 / numberOfTurtlesInTheGroup))    ;;this does not work in NetLogo 4.1.1 (see transition guide for an explanation) 

 ;;show withinGroupHtList  ;;for testing only

 ]
;;show withinGroupHtList  ;;LSP for testing only

end




to calculateHt    ;;observer method
let xbari 0
let sumOfXbariSquared 0
let q 0

while [q < length totalDiversityList]
 [ 
 set xbari mean [item q withinGroupHtList] of patches
 ;;show xbari  ;;LSP for testing only

 set sumOfXbariSquared sumOfXbariSquared + (xbari ^ 2)
 ;;show sumOfXbariSquared  ;;LSP for testing only

 set q q + 1
 ]

set H_t (1 - sumOfXbariSquared)
;;write "Ht:" ;;for testing and printing to the GUI
;;print H_t  ;;for testing and printing to the GUI

set t_f ((1 / sumOfXbariSquared) - 1)
;;write "tf:"  ;;for testing and printing to the GUI
;;print t_f   ;;for testing and printing to the GUI
end




to cultTransmission    ;;turtle method, this represents social learning with copying errors

;; if conformist learning is turned on, each offspring learns the variant that is most frequently displayed within its group (ties broken randomly)
ifelse conformistLearning = true 
[
set culturalVariant one-of modes [culturalVariant] of turtles-here with [age = 1]  ;;ties between modes are broken randomly by using "one-of"
]
[   ;; else, wtih unbiased cultural transmission, the naive individual adopts the variant displayed by...
let teacher one-of turtles-here with [age = 1]   ;;...a randomly chosen individual from within the parental generation of the group.
;;show teacher  ;for testing
set culturalVariant [culturalVariant] of teacher   
]

;;then we allow for some replcation error to modify the naive individual's cultural variant in a stepwise fashion

if innovationType = "50/50"  ;;an innovation is equally likely to increase or decrease the variant by one. NOTE: this is the method used in Premo and Kuhn (2010).
[
if random-float 1 <= errorProb   ;;if a random uniform float is less than or equal to errorProb (mu), then there will be a copying error
 [
  ifelse random-float 1 <= 0.5   ;;with equal probability, add or subtract 1 to the integer copied during cultural transmission 
    [set culturalVariant culturalVariant + 1]
    [set culturalVariant culturalVariant - 1]
 ] 
]

;; forward only single stepwise innovation, not used in the paper 
if innovationType = "100/0"
[
if random-float 1 <= errorProb 
 [set culturalVariant culturalVariant + 1]   ;;in this case, always add 1 to the integer copied during cultural transmission.
]

set totalCultTransEvents totalCultTransEvents + 1  ;;increment the total number of cultural transmission events in the simulation run 

set color culturalVariant  ;;recolor agents according to their culturalVariant value
end
;;this ends the "cultTransmission" method




to colonize    ;;patch method
;;Send half of the current members (rounded to the nearest whole number) to the empty cell. The individuals who will serve as colonizers are chosen randomly.
ask n-of round(count turtles-here / 2) turtles-here [move-to emptyCell]
end




to calculateDifferenceFromAncestral  ;;patch method
;;how different the *group* is from the ancestral state of all zeros
set differenceFromAncestral (abs(modeCulturalVariant))
end




to calculateDifferenceToAllOtherGroups  ;;patch method for calculating d_G
  let sumDiff 0
  let currentPatch self
  
    foreach ([self] of other patches)  ;;for all patches
    [
    let targetPatch ?1  ;;look at each in turn
    if count [turtles-here] of targetPatch > 0 and targetPatch != currentPatch     ;;targetPatch cannot equal currentPatch and it must have members
     [
     ask currentPatch 
       [
       set sumDiff (sumDiff + (abs (modeCulturalVariant - [modeCulturalVariant] of targetPatch)))  ;;sum the absolute value of the difference between the currentPatch's variant and the targetPatch's variant over all traits       
       set differenceToAllOtherGroups (sumDiff / (count other patches with [count turtles-here > 0] - 1))   ;;subtract one here before dividing to avoid counting currentPatch in the denominator
       ]
     ]
   ]
end




;;Collect data in a textfile

to printOutput   ;;observer method, called from within "go"
 ;;write data to an output file called diversityData.txt
 file-open "diversityData.txt"
 file-write ticks 
 file-write count turtles 
 file-write totalDiversity 
 file-write ShannonsIndex 
 file-write H_global 
 file-write H_t 
 file-write H_s 
 file-write t_f                                     
 file-write meanDiffFromAncestral
 file-write CVDiffFromAncestral
 file-write maxDiffFromAncestral
 file-write totalCultTransEvents 
 file-write totalGroupExtinctions 
 file-write totalGroupFissions 
 file-write meanNumberGroupFissions 
 file-write varNumberGroupFissions 
 file-write meanHofGroups 
 file-write varHofGroups 
 file-write meanDiffOtherGroups 
 file-write CVDiffOtherGroups
 file-write meanSIofGroups
 file-write varSIofGroups
 file-print " "
 file-close
end 
@#$#@#$#@
GRAPHICS-WINDOW
302
79
675
473
-1
-1
36.3
1
10
1
1
1
0
1
1
1
0
9
0
9
1
1
1
ticks

BUTTON
7
13
73
46
setup
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
75
13
138
46
go
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
141
13
204
46
step
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

SLIDER
12
208
218
241
groupExtinctionProbMean
groupExtinctionProbMean
0
0.2
0.0010
0.001
1
NIL
HORIZONTAL

SLIDER
11
170
135
203
maxGroupSize
maxGroupSize
0
100
25
5
1
NIL
HORIZONTAL

SLIDER
12
246
218
279
groupExtinctionProbStandDev
groupExtinctionProbStandDev
0
1
0
0.01
1
NIL
HORIZONTAL

SWITCH
14
355
169
388
conformistLearning
conformistLearning
1
1
-1000

SLIDER
15
476
149
509
errorRateMean
errorRateMean
0
0.1
0.01
0.001
1
NIL
HORIZONTAL

SLIDER
15
511
163
544
errorRateStandDev
errorRateStandDev
0
1
0
0.01
1
NIL
HORIZONTAL

PLOT
973
11
1244
193
Difference from Ancestral State (Histogram)
Difference from Ancestral
# of Groups
0.0
40.0
0.0
100.0
true
false
PENS
"default" 1.0 1 -16777216 true

PLOT
681
10
966
192
Difference from Ancestral State
Time
Difference
0.0
10.0
0.0
10.0
true
true
PENS
"mean" 1.0 0 -13345367 true
"sd" 1.0 0 -2674135 true
"var" 1.0 0 -10899396 true
"CV" 1.0 0 -11221820 true

SWITCH
13
283
156
316
localReplacement
localReplacement
0
1
-1000

SLIDER
206
13
298
46
seed
seed
0
1000000
414897
1
1
NIL
HORIZONTAL

PLOT
681
198
966
370
Difference from All Other Groups
Time
Difference from All Other Groups
0.0
10.0
0.0
10.0
true
true
PENS
"mean" 1.0 0 -13345367 true
"sd" 1.0 0 -2674135 true
"var" 1.0 0 -10899396 true
"CV" 1.0 0 -11221820 true

PLOT
972
198
1243
370
Difference from All Other Groups (Histogram)
Mean Difference of Modes
# of Groups
0.0
20.0
0.0
100.0
true
false
PENS
"default" 1.0 1 -16777216 true

SWITCH
13
318
172
351
replaceBasedOnSize
replaceBasedOnSize
1
1
-1000

CHOOSER
15
428
111
473
innovationType
innovationType
"50/50" "100/0"
0

SLIDER
120
49
287
82
dataCollectionInterval
dataCollectionInterval
0
1000
1000
100
1
NIL
HORIZONTAL

SWITCH
8
49
117
82
collectData
collectData
0
1
-1000

PLOT
682
375
968
561
Population Cultural Diversity
Time
Diveristy
0.0
10.0
0.0
1.0
true
true
PENS
"Total" 1.0 0 -16777216 true
"Within" 1.0 0 -2674135 true
"Between" 1.0 0 -13345367 true

PLOT
972
375
1243
561
Group Cultural Diversity
Time
H
0.0
10.0
0.0
1.0
true
true
PENS
"mean" 1.0 0 -13345367 true
"sd" 1.0 0 -2674135 true
"var" 1.0 0 -10899396 true
"CV" 1.0 0 -11221820 true

TEXTBOX
14
147
139
181
Group variables
14
0.0
1

TEXTBOX
14
406
164
424
Innovation variables
14
0.0
1

MONITOR
569
31
675
76
Population Size
count turtles
0
1
11

TEXTBOX
356
477
643
505
darker shades = relatively similar to ancestral state\nlighter shades = very different from ancestral state
11
0.0
1

CHOOSER
8
84
120
129
initialPopulation
initialPopulation
"homogeneous" "heterogeneous"
0

SLIDER
122
84
288
117
experimentDuration
experimentDuration
0
100000000
50000
1000
1
NIL
HORIZONTAL

@#$#@#$#@
WHAT IS IT?
-----------
A spatially explicit agent-based model used to collect the data analyzed in Premo and Kuhn (2010). 

version 1.0  
Oct. 2010
Leipzig


HOW TO USE IT
-------------

NOTE: this model works with NetLogo version 4.0 or 4.1

1. Use sliders and choosers on the Interface to set the parameters to your liking.
2. If you would like to collect data in a text file, switch collectData to "on"
3. Hit "setup" button
4. Hit "go" button to run the model for the number of time steps defined in experimentDuration, and hit "go" a second time to pause
5. To step through the model one time step at a time, hit "step" button.
6. You can rerun the same simulations we ran for the paper by going to 
Tools-->BehaviorSpace and selecting one of the experiments that appears in the menu.



MODEL DESCRIPTION
------------

*Purpose*
This model is designed to help us learn about how a demographic variable--localized group extinction rate--affects the evolution of neutral cultural diversity in an idealized structured population.  We simulate populations with different group extinction rates to study what effect the frequency of local extinctions has on total diversity, long-term cumulative culture change, and regional cultural differentiation in a spatially structured population of constant size and density.  The results show an inverse relationship between the frequency of local extinction and the amount and rate of culture change through time.  Frequent local extinctions also constrain differentiation between groups.


*Agent classes, variables, & temporal and spatial scales*
Our model employs two classes of agents: individuals and groups.  Individuals serve as the vehicles of cultural transmission.  Individuals have only 3 variables: one representing age (age), one representing the probability of making a copying error when learning (errorProb), and one representing a neutral cultural variant (culturalVariant).  Age can be assigned one of two possible values: 0 (born during the current time step) or 1 (born during the previous time step).  errorProb is given by a real number bound by 0 and 1.  culturalVariant can take the value of any integer.  Individuals have only two methods: die and learn.  An individual dies if its group goes extinct or its age=1 at the end of a time step.  The method, learn, defines the way in which each naive "offspring" (i.e., and individual with age=0) acquires its culturalVariant from a member of the "parental" generation (i.e., an individual with age=1).  This model implements 2 mechanisms of cultural transmission: unbiased and conformist (see Submodels).
	
In the context of this model, groups are best described as spatially explicit containers of individuals.  Groups provide the population with spatial structure.  Each group is characterized by a unique Cartesian coordinate, a group extinction probability (groupExtinctionProb), which is represented by a real number bound by 0 and 1, and modeCulturalVariant, which contains the mode of the culturalVariants displayed by its members.   Groups have only one method, called fission.
	
The model proceeds in simulated time steps (or ticks).  Each time step represents a single generation.  That is to say that, by the end of each time step, the entire "parental" generation--those individuals alive at the beginning of the time step--has been replaced by a new generation of "offspring."
	
The model is spatially explicit.  The spatial environment is a grid of regularly spaced and shaped square cells.  The opposite edges of the grid are wrapped to avoid edge effects.  Although cell size does not equate to an empirical value, one can think of it as the area needed to support the subsistence activities of a single social group (N=25) within an idealized homogeneous landscape.  Thus, each cell represents a single group, which can contain up to N individuals. 


*Process Overview and Scheduling*
Each time step is composed of 5 distinct processes, which occur in the following order: individuals get older, groups are exposed to risk of extinction, the "offspring" generation is created, cultural variants are transmitted from the parental generation to the offspring generation, and the "parental" generation is culled.  

At the very beginning of each time step, all living individuals get older. They update the value of their age variable from 0 to 1 to reflect the fact that they are now part of the "parental" generation and can serve as teachers later in the time step.  

Second, all groups are exposed to localized extinction.  If a real number chosen randomly from a uniform distribution bound by 0 and 1 is less than or equal to a groups groupExtinctionProb, then the individuals who are members of that group die, and they are removed from the simulation immediately.  Following an extinction event, the cell is empty.  Each empty cell is repopulated with members of the "parental" generation taken from a randomly chosen neighboring group [see fission in Submodels]).  Empty cells are repopulated after all groups have been exposed to a chance of local extinction.  

Third, the "offspring" generation is created, which means that 25 new individuals are created in each group.  Members of the "offspring" generation are distinguished from those that remain from the parental generation by their age (0 for offspring generation, 1 for parental generation) and by the fact that they have not yet adopted a cultural variant. 

Fourth, all members of the newly created "offspring" generation undergo cultural transmission.  The model implements two very different mechanisms of cultural transmission: unbiased and conformist cultural transmission.  In both cases, however, cultural transmission occurs within groups only. There is no form of intergroup cultural transmission in the model.  With unbiased cultural transmission, each "offspring" learns (i.e., copies) the variant expressed by its "teacher."  Each "offspring" randomly selects its teacher (with replacement) from among the "parental" generation survivors who inhabit the same group that the "offspring" occupies.  With conformist biased transmission, the "offspring" does not learn from a "teacher," but rather it adopts the cultural variant that is most common (i.e., the modal variant) among the "parental" generation survivors who inhabit the same group as the "offspring."  In the event that there is more than one mode in the variants displayed by the parental generation in a group, each nave individual attempts to copy one of the modal variants chosen at random.  Cultural transmission is noisy.  The copying error rate, errorProb, provides the probability that an "offspring" makes a mistake when acquiring its variant during cultural transmission.  Regardless of the mechanism of cultural transmission, such errors always result in the "offspring" adopting a variant that is either one integer larger or one integer smaller than the integer it was trying to copy.  In this sense, copying error follows a one-dimensional random walk with a step length of 1.  See submodels for more details on cultural transmission and copying errors.

Finally, all remaining members of the "parental" generation (i.e., age=1) are culled from the simulation.  As a result, the population size at the end of a time step is the same as it was at the beginning of the time step, but all of the individuals belong to the "offspring" generation (i.e., age=0).


*Design Concepts*
Evolution.  In the context of this model, evolution refers to change in cultural variant frequencies in a structured population through time.  Because cultural variants are selectively neutral (i.e., non-adaptive) in this model, the results speak only to neutral evolution.

Stochasticity. Stochasticity is incorporated into many aspects of this nondeterministic model: copying errors and local extinctions are represented probabilistically, agent order is randomized before every process, teachers are chosen randomly from among the set of eligible candidates, and the groups tabbed to fission in order to recolonize an empty cell are chosen randomly from among the empty cells 8 Moore neighbors.


*Initialization*
At the start of each simulation, all groups (n=100) possess the maximum number of individuals (N=25), for a total of 100 * 25 = 2500 individuals. It is preferable to assess demographic effects on diversity in systems that are at equilibrium. In the absence of selection, cultural diversity reaches equilibrium when the rate that new variants are introduced via copying errors matches the rate they are lost to drift. The number of generations required to reach equilibrium varies with population size, copying error rate, population structure, and, in our model, the frequency of local extinctions.  When the copying error rate is very low, there are no local extinctions, and the starting population is perfectly homogeneous (i.e., all individuals display culturalVariant=0 at t0), many hundreds of thousands of generations must pass before cultural diversity approaches equilibrium.  Metapopulations reach equilibrium more quickly if every individual displays a unique value at culturalVariant (in this case, an integer chosen randomly from between 0 and 108) at the start of the simulation. When starting with heterogeneous metapopulations, we found that 50,000 time steps was sufficient for cultural diversity to reach equilibrium for all combinations of copyErrorProb and groupExtinctionProb tested here (see main text).  

In addition to data collected under equilibrium conditions, we analyze data collected from metapopulations that are not at equilibrium. There are two reasons for this. Starting from heterogeneous metapopulations complicates the task of measuring the effects of local extinctions on distance-based measures of group differentiation and cultural change, especially when groupExtinctionProb is very low or zero. A less pragmatic but no less important issue is that, while equilibrium serves as a useful convention for providing a clearer understanding of the effect of local extinctions on some diversity measures, it is not meant to reflect reality. It is not known whether cultural diversity ever reaches equilibrium in societies, nor is this assumption necessary here. The non-equilibrium data were collected after 100,000 time steps from metapopulations in which every individual displayed a culturalVariant of 0 at the start of the simulation. This complementary set of experiments allows us to study the effects of local extinctions on diversity measures, distance-based measures of group differentiation, and rates of cultural change as a function of time.    

The table below provides the values used to initialize the simulations for the equilibrium and non-equilibrium experiments.

Parameter values used to initialize the simulations.
________________________________________________________
Standard parameters
   Maximum group size (N)...........................................25
   Number of groups (n)..............................................100

Experimental parameters
   groupExtinctionProb (e)...................0, 0.001, 0.01, 0.1
   copyErrorProb ()...........0.00001, 0.0001, 0.001, 0.01
   culturalTransmission...................unbiased, conformist

Random number seeds
   seed.....................................1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 
        ............................11, 12, 13, 14, 15, 16, 17, 18, 19, 20
________________________________________________________


*Data Collection*
Data are collected at the end of each simulation.  We collect data at the level of groups and the level of the population.  From each group, we collect the modal cultural variant (d_A), the mean difference between its modal variant and all other groups modal variants (d_G), and Shannons H.  At the level of the entire population, we collect variant richness (the total number of unique cultural variants displayed by the entire population), Shannons H, total diversity (H_T), within-group diversity (H_S), maximum distance from ancestral (d_A max), and the mean of the groups difference from all other groups (dbar_G).


*Submodels*
Group dynamics: local extinction and fission. 
As described above, when a group undergoes a localized extinction event, all of the individuals within it are removed from the simulation.  To repopulate the empty cell with some members of the parental generation who will serve as possible teachers for the next generation in that location, a group from the empty cells Moore neighborhood is randomly chosen to fission.  Aside from being adjacent to the empty group, the only other requirement for serving as a source of "colonizers" is that the group have at least 2 members.  Once chosen, the group sends half of its individuals (rounded to the nearest whole number) to the empty cell. 

Cultural transmission (learn). 
All cultural variants are selectively neutral.  All cultural transmission occurs within spatially defined groups between the parental generation and the offspring generation.  The model implements two mechanisms of cultural transmission (unbiased transmission and conformist biased transmission) although each simulation run can involve only one or the other.

Every unbiased cultural transmission event involves a nave offspring who has yet to adopt a culturalVariant and an experienced teacher from the parental generation.  The offspring copies the culturalVariant expressed by its teacher.  Each offspring randomly chooses its teacher (with replacement) from the set of individuals who are members of the parental generation and members of the spatially defined group of which the offspring is currently a member.  

Conformist cultural transmission works differently.  With conformist biased transmission, the nave offspring copies the variant that is most commonly displayed by the members of the parental generation who reside in its group.  In cases where there are two or more modal variants, the offspring chooses one of them randomly.

Regardless of which mechanism of cultural transmission is used, nave individuals do not copy variants perfectly.  A nave individual makes a mistake when copying a variant with probability errorProb.  Copy errors always result in the offspring adopting a cultural variant that is either one step greater than or less than the integer it was trying to copy.  In the parlance of population genetics, copying errors follow a single stepwise mutation model.


*Noteworthy model assumptions*
Our model assumptions are purposefully conservative.  Here, we briefly discuss some of the more important assumptions of the present version of the model.

The model does not allow a naive individual to learn from a member of a different spatially defined group--cultural transmission occurs within groups only.  Allowing for cultural variants to be transmitted across group boundaries, for example, would likely affect the results reported here.  We would expect the magnitude of the effect of local group extinction on cultural diversity to decrease as the rate of intergroup transmission increased.  Still, we would expect that our general finding--that frequent local group extinctions decrease the amount and rate of neutral cultural change and inhibit regional differentiation between groups--would hold true for low levels of intergroup transmission.  However, it may be that, in the presence of relatively high intergroup transmission rates, groupExtinctionProb would need to be higher than what we tested here in order to show similar effects on cultural diversity.

This model also does not allow for horizontal cultural transmission: individuals can only learn from members of the previous generation, never from members of their own generation.  It is unclear how including horizontal transmission would affect our results, and this might be worth investigating further.

Copying errors follow what population geneticists call a single stepwise mutation model.  This kind of mutation model is often used to study neutral microsatellite, or STR (Short Tandem Repeat), loci in population genetics. Modifying the way in which copying errors affect cultural variants--for example, by using an "infinite alleles" approach instead of the single stepwise model or by only allowing copying errors to only increase cultural variants in all cases--may yield results that differ from those reported in the text.  However, it should be noted that using an infinite alleles approach may complicate the task of measuring change and that using a uni-directional stepwise approach may not allow one to make use of F_ST.



THINGS TO TRY
-------------
Switch the conformistLearning button from "off" to "on" or vice versa during a run and notice what this does to the level of total diversity and how total diversity is partitioned within and between groups.



CREDITS AND REFERENCES
----------------------
This model was created and programmed by Luke Premo (Department of Human Evolution, Max Planck Institute for Evolutionary Anthropology, Leipzig) with conceptual contributions by Steve Kuhn (School of Anthropology, University of Arizona).  This research was supported by the Max Planck Society.

Questions, comments, feedback: luke.premo@eva.mpg.de
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 4.1.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="experiment_er0001_nonequilibrium" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100001"/>
    <enumeratedValueSet variable="initialPopulation">
      <value value="&quot;homogeneous&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="experimentDuration">
      <value value="100000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maxGroupSize">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="errorRateStandDev">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="collectData">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dataCollectionInterval">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovationType">
      <value value="&quot;50/50&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replaceBasedOnSize">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="groupExtinctionProbStandDev">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="localReplacement">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="conformistLearning">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="groupExtinctionProbMean">
      <value value="0"/>
      <value value="0.0010"/>
      <value value="0.01"/>
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="errorRateMean">
      <value value="1.0E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seed">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
      <value value="5"/>
      <value value="6"/>
      <value value="7"/>
      <value value="8"/>
      <value value="9"/>
      <value value="10"/>
      <value value="11"/>
      <value value="12"/>
      <value value="13"/>
      <value value="14"/>
      <value value="15"/>
      <value value="16"/>
      <value value="17"/>
      <value value="18"/>
      <value value="19"/>
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment_er001_nonequilibrium" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100001"/>
    <enumeratedValueSet variable="initialPopulation">
      <value value="&quot;homogeneous&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="experimentDuration">
      <value value="100000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maxGroupSize">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="errorRateStandDev">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="collectData">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dataCollectionInterval">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovationType">
      <value value="&quot;50/50&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replaceBasedOnSize">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="groupExtinctionProbStandDev">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="localReplacement">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="conformistLearning">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="groupExtinctionProbMean">
      <value value="0"/>
      <value value="0.0010"/>
      <value value="0.01"/>
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="errorRateMean">
      <value value="0.0010"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seed">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
      <value value="5"/>
      <value value="6"/>
      <value value="7"/>
      <value value="8"/>
      <value value="9"/>
      <value value="10"/>
      <value value="11"/>
      <value value="12"/>
      <value value="13"/>
      <value value="14"/>
      <value value="15"/>
      <value value="16"/>
      <value value="17"/>
      <value value="18"/>
      <value value="19"/>
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment_er01_nonequilibrium" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100001"/>
    <enumeratedValueSet variable="initialPopulation">
      <value value="&quot;homogeneous&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="experimentDuration">
      <value value="100000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maxGroupSize">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="errorRateStandDev">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="collectData">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dataCollectionInterval">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovationType">
      <value value="&quot;50/50&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replaceBasedOnSize">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="groupExtinctionProbStandDev">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="localReplacement">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="conformistLearning">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="groupExtinctionProbMean">
      <value value="0"/>
      <value value="0.0010"/>
      <value value="0.01"/>
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="errorRateMean">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seed">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
      <value value="5"/>
      <value value="6"/>
      <value value="7"/>
      <value value="8"/>
      <value value="9"/>
      <value value="10"/>
      <value value="11"/>
      <value value="12"/>
      <value value="13"/>
      <value value="14"/>
      <value value="15"/>
      <value value="16"/>
      <value value="17"/>
      <value value="18"/>
      <value value="19"/>
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment_er00001_nonequilibrium" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100001"/>
    <enumeratedValueSet variable="initialPopulation">
      <value value="&quot;homogeneous&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="experimentDuration">
      <value value="100000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maxGroupSize">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="errorRateStandDev">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="collectData">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dataCollectionInterval">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovationType">
      <value value="&quot;50/50&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replaceBasedOnSize">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="groupExtinctionProbStandDev">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="localReplacement">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="conformistLearning">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="groupExtinctionProbMean">
      <value value="0"/>
      <value value="0.0010"/>
      <value value="0.01"/>
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="errorRateMean">
      <value value="1.0E-5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seed">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
      <value value="5"/>
      <value value="6"/>
      <value value="7"/>
      <value value="8"/>
      <value value="9"/>
      <value value="10"/>
      <value value="11"/>
      <value value="12"/>
      <value value="13"/>
      <value value="14"/>
      <value value="15"/>
      <value value="16"/>
      <value value="17"/>
      <value value="18"/>
      <value value="19"/>
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment_conformist_nonequilibrium" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100001"/>
    <enumeratedValueSet variable="initialPopulation">
      <value value="&quot;homogeneous&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="experimentDuration">
      <value value="100000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maxGroupSize">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="errorRateStandDev">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="collectData">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovationType">
      <value value="&quot;50/50&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replaceBasedOnSize">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="groupExtinctionProbStandDev">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="localReplacement">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="conformistLearning">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="groupExtinctionProbMean">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="errorRateMean">
      <value value="1.0E-4"/>
      <value value="0.0010"/>
      <value value="0.01"/>
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seed">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
      <value value="5"/>
      <value value="6"/>
      <value value="7"/>
      <value value="8"/>
      <value value="9"/>
      <value value="10"/>
      <value value="11"/>
      <value value="12"/>
      <value value="13"/>
      <value value="14"/>
      <value value="15"/>
      <value value="16"/>
      <value value="17"/>
      <value value="18"/>
      <value value="19"/>
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment_er0001_equilibrium" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="50001"/>
    <enumeratedValueSet variable="initialPopulation">
      <value value="&quot;heterogeneous&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="experimentDuration">
      <value value="50000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maxGroupSize">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="errorRateStandDev">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="collectData">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dataCollectionInterval">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovationType">
      <value value="&quot;50/50&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replaceBasedOnSize">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="groupExtinctionProbStandDev">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="localReplacement">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="conformistLearning">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="groupExtinctionProbMean">
      <value value="0"/>
      <value value="0.0010"/>
      <value value="0.01"/>
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="errorRateMean">
      <value value="1.0E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seed">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
      <value value="5"/>
      <value value="6"/>
      <value value="7"/>
      <value value="8"/>
      <value value="9"/>
      <value value="10"/>
      <value value="11"/>
      <value value="12"/>
      <value value="13"/>
      <value value="14"/>
      <value value="15"/>
      <value value="16"/>
      <value value="17"/>
      <value value="18"/>
      <value value="19"/>
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment_er001_equilibrium" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="50001"/>
    <enumeratedValueSet variable="initialPopulation">
      <value value="&quot;heterogeneous&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="experimentDuration">
      <value value="50000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maxGroupSize">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="errorRateStandDev">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="collectData">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dataCollectionInterval">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovationType">
      <value value="&quot;50/50&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replaceBasedOnSize">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="groupExtinctionProbStandDev">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="localReplacement">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="conformistLearning">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="groupExtinctionProbMean">
      <value value="0"/>
      <value value="0.0010"/>
      <value value="0.01"/>
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="errorRateMean">
      <value value="0.0010"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seed">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
      <value value="5"/>
      <value value="6"/>
      <value value="7"/>
      <value value="8"/>
      <value value="9"/>
      <value value="10"/>
      <value value="11"/>
      <value value="12"/>
      <value value="13"/>
      <value value="14"/>
      <value value="15"/>
      <value value="16"/>
      <value value="17"/>
      <value value="18"/>
      <value value="19"/>
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment_er01_equilibrium" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="50001"/>
    <enumeratedValueSet variable="initialPopulation">
      <value value="&quot;heterogeneous&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="experimentDuration">
      <value value="50000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maxGroupSize">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="errorRateStandDev">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="collectData">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dataCollectionInterval">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovationType">
      <value value="&quot;50/50&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replaceBasedOnSize">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="groupExtinctionProbStandDev">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="localReplacement">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="conformistLearning">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="groupExtinctionProbMean">
      <value value="0"/>
      <value value="0.0010"/>
      <value value="0.01"/>
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="errorRateMean">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seed">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
      <value value="5"/>
      <value value="6"/>
      <value value="7"/>
      <value value="8"/>
      <value value="9"/>
      <value value="10"/>
      <value value="11"/>
      <value value="12"/>
      <value value="13"/>
      <value value="14"/>
      <value value="15"/>
      <value value="16"/>
      <value value="17"/>
      <value value="18"/>
      <value value="19"/>
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment_er00001_equilibrium" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="50001"/>
    <enumeratedValueSet variable="initialPopulation">
      <value value="&quot;heterogeneous&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="experimentDuration">
      <value value="50000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maxGroupSize">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="errorRateStandDev">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="collectData">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dataCollectionInterval">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovationType">
      <value value="&quot;50/50&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replaceBasedOnSize">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="groupExtinctionProbStandDev">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="localReplacement">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="conformistLearning">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="groupExtinctionProbMean">
      <value value="0"/>
      <value value="0.0010"/>
      <value value="0.01"/>
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="errorRateMean">
      <value value="1.0E-5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seed">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
      <value value="5"/>
      <value value="6"/>
      <value value="7"/>
      <value value="8"/>
      <value value="9"/>
      <value value="10"/>
      <value value="11"/>
      <value value="12"/>
      <value value="13"/>
      <value value="14"/>
      <value value="15"/>
      <value value="16"/>
      <value value="17"/>
      <value value="18"/>
      <value value="19"/>
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
